@@ -3,9 +3,10 @@ package Net::NicoVideo::Content::MylistPage;
 use strict;
 use warnings;
 use vars qw($VERSION);
-$VERSION = '0.01_17';
+$VERSION = '0.28';
+
+use base qw(Net::NicoVideo::Content Class::Accessor::Fast);
 
-use base qw(Class::Accessor::Fast);
 use vars qw(@Members);
 @Members = qw(
 token
@@ -13,11 +14,31 @@ token
 
 __PACKAGE__->mk_accessors(@Members);
 
-sub members {
+sub members { # implement
     my @copy = @Members;
     @copy;
 }
 
+sub parse { # implement
+    my $self = shift;
+    $self->load($_[0]) if( defined $_[0] );
+
+    my $content = $self->_decoded_content;
+    if( $content =~ /NicoAPI\.token\s*=\s*"([-\w]+)"/ ){
+        $self->token( $1 );
+    }
+
+    # status
+    if( $self->token ){
+        $self->set_status_success;
+    }else{
+        $self->set_status_error;
+    }
+    
+    return $self;
+}
+
+
 1;
 __END__
 
