@@ -3,7 +3,7 @@ package Net::NicoVideo::Request;
 use strict;
 use warnings;
 use vars qw($VERSION);
-$VERSION = '0.01_21';
+$VERSION = '0.27';
 
 use base qw(HTTP::Request);
 use HTTP::Request::Common;
@@ -16,9 +16,9 @@ sub get {
 }
 
 sub login {
-    my $class = shift;
-    my $email = shift or croak "missing mandatory parameter";
-    my $password = shift or croak "missing mandatory parameter";
+    my ($class, $email, $password) = @_;
+    croak "missing mandatory parameter"
+        if( ! defined $email or ! defined $password );
     my $url = 'https://secure.nicovideo.jp/secure/login?site=niconico';
     return POST $url, [
         next_url    => '',
@@ -28,44 +28,49 @@ sub login {
 }
 
 sub thumbinfo {
-    my $class = shift;
-    my $video_id = shift or croak "missing mandatory parameter";
+    my ($class, $video_id) = @_;
+    croak "missing mandatory parameter"
+        if( ! defined $video_id );
     my $url = 'http://ext.nicovideo.jp/api/getthumbinfo/'.$video_id;
     return GET $url;
 }
 
 sub flv {
-    my $class = shift;
-    my $video_id = shift or croak "missing mandatory parameter";
+    my ($class, $video_id) = @_;
+    croak "missing mandatory parameter"
+        if( ! defined $video_id);
     my $url = 'http://flapi.nicovideo.jp/api/getflv/'.$video_id;
     my $params = $video_id =~ /^nm/ ? ['as3' => 1] : [];
     return POST $url, $params;
 }
 
 sub watch {
-    my $class = shift;
-    my $video_id = shift or croak "missing mandatory parameter";
+    my ($class, $video_id) = @_;
+    croak "missing mandatory parameter"
+        if( ! defined $video_id);
     my $url = 'http://www.nicovideo.jp/watch/'.$video_id;
     return GET $url;
 }
 
 sub thread {
-    my $class = shift;
-    my $ms = shift or croak "missing mandatory parameter";
-    my $thread_id = shift or croak "missing mandatory parameter";
-    my $opts = shift || {};
+    my ($class, $ms, $thread_id, $opts) = @_;
+    croak "missing mandatory parameter"
+        if( ! defined $ms or ! defined $thread_id );
+    $opts ||= {};
     return POST $ms,
         Content => sprintf '<thread thread="%s" version="20061206" res_from="-%d"%s></thread>',
             $thread_id, ($opts->{'chats'} || 250), ($opts->{'fork'} ? ' fork="1"' : '');    
 }
 
 sub tag_rss {
-    my $class = shift;
-    my $keyword = shift or croak "missing mandatory parameter";
-    my $params = shift || {};
+    my ($class, $keyword, $params) = @_;
+    croak "missing mandatory parameter"
+        if( ! defined $keyword );
+    $params ||= {};
     $params->{rss} = '2.0';
     my @q = ();
-    while( my ($k, $v) = each %{$params} ){
+    for my $k ( sort keys %{$params} ){
+        my $v = $params->{$k};
         $v = '' unless( defined $v );
         push @q, sprintf('%s=%s', uri_escape_utf8($k), uri_escape_utf8($v));
     }
@@ -75,40 +80,42 @@ sub tag_rss {
 }
 
 sub mylist_rss {
-    my $class = shift;
-    my $mylist_id = shift or croak "missing mandatory parameter";
+    my ($class, $mylist_id) = @_;
+    croak "missing mandatory parameter"
+        if( ! defined $mylist_id );
     my $url = 'http://www.nicovideo.jp/mylist/'.$mylist_id.'?rss=2.0';
     return GET $url;
 }
 
 sub mylist_page {
-    my $class = shift;
+    my ($class) = @_;
     return GET 'http://www.nicovideo.jp/my/mylist';
 }
 
 sub mylist_item {
-    my $class = shift;
-    my $video_id = shift or croak "missing mandatory parameter";
+    my ($class, $video_id) = @_;
+    croak "missing mandatory parameter"
+        if( ! defined $video_id );
     my $url = 'http://www.nicovideo.jp/mylist_add/video/'.$video_id;
     return GET $url;
 }
 
 sub mylistgroup_list {
-    my $class = shift;
+    my ($class) = @_;
     return POST 'http://www.nicovideo.jp/api/mylistgroup/list';
 }
 
 sub mylistgroup_get {
-    my $class = shift;
-    my $mylist_id = shift or croak "missing mandatory parameter";
+    my ($class, $mylist_id) = @_;
+    croak "missing mandatory parameter"
+        if( ! defined $mylist_id );
     my $params = [ group_id => $mylist_id ];
     return POST 'http://www.nicovideo.jp/api/mylistgroup/get', $params;
 }
 
 sub mylistgroup_add {
-    my $class = shift;
-    my $params = shift || {};
-    my $token = shift;
+    my ($class, $params, $token) = @_;
+    $params ||= {};
     return POST 'http://www.nicovideo.jp/api/mylistgroup/add', [
         token       => $token,
         name        => $params->{name},
@@ -120,9 +127,8 @@ sub mylistgroup_add {
 }
 
 sub mylistgroup_update {
-    my $class = shift;
-    my $params = shift || {};
-    my $token = shift;
+    my ($class, $params, $token) = @_;
+    $params ||= {};
     return POST 'http://www.nicovideo.jp/api/mylistgroup/update', [
         token       => $token,
         group_id    => $params->{group_id},
@@ -135,9 +141,8 @@ sub mylistgroup_update {
 }
 
 sub mylistgroup_delete {
-    my $class = shift;
-    my $params = shift || {};
-    my $token = shift;
+    my ($class, $params, $token) = @_;
+    $params ||= {};
     return POST 'http://www.nicovideo.jp/api/mylistgroup/delete', [
         token       => $token,
         group_id    => $params->{group_id},
@@ -145,16 +150,16 @@ sub mylistgroup_delete {
 }
 
 sub mylist_list {
-    my $class = shift;
-    my $group_id = shift or croak "missing mandatory parameter";
+    my ($class, $group_id) = @_;
+    croak "missing mandatory parameter"
+        if( ! defined $group_id );
     my $params = [ group_id => $group_id ];
     return POST 'http://www.nicovideo.jp/api/mylist/list', $params;
 }
 
 sub mylist_add {
-    my $class = shift;
-    my $params = shift || {};
-    my $token = shift;
+    my ($class, $params, $token) = @_;
+    $params ||= {};
     return POST 'http://www.nicovideo.jp/api/mylist/add', [
         token       => $token,
         group_id    => $params->{group_id},
@@ -165,9 +170,8 @@ sub mylist_add {
 }
 
 sub mylist_update {
-    my $class = shift;
-    my $params = shift || {};
-    my $token = shift;
+    my ($class, $params, $token) = @_;
+    $params ||= {};
     return POST 'http://www.nicovideo.jp/api/mylist/update', [
         token       => $token,
         group_id    => $params->{group_id},
@@ -178,9 +182,8 @@ sub mylist_update {
 }
 
 sub mylist_delete {
-    my $class = shift;
-    my $params = shift || {};
-    my $token = shift;
+    my ($class, $params, $token) = @_;
+    $params ||= {};
     my @args = $class->make_id_list($params->{item_type}, $params->{item_id});
     push @args, (
         token       => $token,
@@ -190,9 +193,8 @@ sub mylist_delete {
 }
 
 sub mylist_move {
-    my $class = shift;
-    my $params = shift || {};
-    my $token = shift;
+    my ($class, $params, $token) = @_;
+    $params ||= {};
     my @args = $class->make_id_list($params->{item_type}, $params->{item_id});
     push @args, (
         token           => $token,
@@ -203,9 +205,8 @@ sub mylist_move {
 }
 
 sub mylist_copy {
-    my $class = shift;
-    my $params = shift || {};
-    my $token = shift;
+    my ($class, $params, $token) = @_;
+    $params ||= {};
     my @args = $class->make_id_list($params->{item_type}, $params->{item_id});
     push @args, (
         token           => $token,
@@ -215,13 +216,10 @@ sub mylist_copy {
     return POST 'http://www.nicovideo.jp/api/mylist/copy', \@args;
 }
 
-
 sub make_id_list {
-    my $class = shift;
-    my $item_type = shift;
-    my $item_id = shift;
-    croak "missing mandatory parameter" unless( defined $item_type );
-    croak "missing mandatory parameter" unless( defined $item_id );
+    my ($class, $item_type, $item_id) = @_;
+    croak "missing mandatory parameter"
+        if( ! defined $item_type or ! defined $item_id );
     my @id_list = ('id_list['.$item_type.'][]' => $item_id);
     return wantarray ? @id_list : \@id_list;
 }
