@@ -1,10 +1,13 @@
 #!/usr/bin/env perl
 
-use 5.12.0;
+use strict;
 use warnings;
+use feature qw/say/;
+
 use Net::NicoVideo;
 use Data::Dumper;
 local $Data::Dumper::Indent = 1;
+
 binmode(STDOUT, ":utf8");
 binmode(STDERR, ":utf8");
 
@@ -24,7 +27,6 @@ unless( $api->is_status_ok ){
     say $api->error_description;
 }else{
     say Data::Dumper::Dumper([$api]);
-    say ref($api);
 }
 
 1;
