@@ -1,23 +1,16 @@
 #!/usr/bin/env perl
 
-use 5.12.0;
+use strict;
 use warnings;
+use feature qw/say/;
+
 use Net::NicoVideo;
 use Net::NicoVideo::Content::NicoAPI;
 use Getopt::Std;
-use Data::Dumper;
-local $Data::Dumper::Indent = 1;
+
 binmode(STDOUT, ":utf8");
 binmode(STDERR, ":utf8");
 
-sub dump_as_yaml {
-    require YAML;
-    require YAML::Dumper;
-    my $dumper = YAML::Dumper->new;
-    $dumper->indent_width(4);
-    $dumper->dump(@_);
-}
-
 my $opts = {};
 getopts('d:i:o:ps:u:', $opts);
 my $name = $ARGV[0] or die "usage: $0 [options...] name\n";
@@ -33,8 +26,13 @@ my $mylistgroup = Net::NicoVideo::Content::NicoAPI::MylistGroup->new({
     });
 
 my $nnv = Net::NicoVideo->new;
-my $added = $nnv->add_mylistgroup($mylistgroup);
-say dump_as_yaml($added);
+my $api = $nnv->add_mylistgroup($mylistgroup);
+
+require Data::Dumper;
+local  $Data::Dumper::Indent;
+$Data::Dumper::Indent = 1;
+say Data::Dumper::Dumper($api);
+
 
 1;
 __END__
