@@ -1,17 +1,20 @@
 #!/usr/bin/env perl
 
-use 5.12.0;
+use strict;
 use warnings;
+use feature qw/say/;
+
 use Net::NicoVideo;
 use Net::NicoVideo::Content::NicoAPI;
 use Data::Dumper;
 local $Data::Dumper::Indent = 1;
+
 binmode(STDOUT, ":utf8");
 binmode(STDERR, ":utf8");
 
-my $group_id    = $ARGV[0] or die "usage: $0 group_id target_id item_id\n";
-my $target_id   = $ARGV[1] or die "usage: $0 group_id target_id item_id\n";
-my $item_id     = $ARGV[2] or die "usage: $0 group_id target_id item_id\n";
+my $group_id    = $ARGV[0] or die "usage: $0 src-group_id dst-group_id item_id\n";
+my $target_id   = $ARGV[1] or die "usage: $0 src-group_id dst-group_id item_id\n";
+my $item_id     = $ARGV[2] or die "usage: $0 src-group_id dst-group_id item_id\n";
 
 my $item = Net::NicoVideo::Content::NicoAPI::MylistItem->new({
     item_type   => 0,
@@ -29,5 +32,6 @@ unless( $api->is_status_ok ){
     say ref($api);
 }
 
+
 1;
 __END__
