@@ -1,10 +1,13 @@
 #!/usr/bin/env perl
 
-use 5.12.0;
+use strict;
 use warnings;
+use feature qw/say/;
+
 use Net::NicoVideo;
 use Getopt::Std;
 
+
 my $opts = { c => 250 };
 getopts('c:f',$opts);
 
@@ -12,12 +15,12 @@ my $video_id = $ARGV[0] or die "usage: $0 [-c num] [-f] video_id \n";
 
 my $nnv = Net::NicoVideo->new;
 
-my $thread  = $nnv->fetch_thread($video_id, { chats => $opts->{c}, 'fork' => $opts->{f} } );
+my $thread = $nnv->fetch_thread($video_id, { chats => $opts->{c}, 'fork' => $opts->{f} } );
 
-# it have to set after fetch_thread, why??
+# binmode has to be set after fetch_thread, why??
 binmode(STDOUT, ":utf8");
 
-say $thread->count;
+say "# there are ", $thread->count, " comments";
 for my $comm ( $thread->get_comments ){
     say $comm->value;
 }
