@@ -1,22 +1,17 @@
 #!/usr/bin/env perl
 
-use 5.12.0;
+use strict;
 use warnings;
+use feature qw/say/;
+
 use Net::NicoVideo;
 use Net::NicoVideo::Content::NicoAPI;
 use Data::Dumper;
-local $Data::Dumper::Indent = 1;
+local $Data::Dumper::Indent;
+
 binmode(STDOUT, ":utf8");
 binmode(STDERR, ":utf8");
 
-sub dump_as_yaml {
-    require YAML;
-    require YAML::Dumper;
-    my $dumper = YAML::Dumper->new;
-    $dumper->indent_width(4);
-    $dumper->dump(@_);
-}
-
 my $group_id = $ARGV[0] or die "usage: $0 group_id\n";
 
 my $nnv = Net::NicoVideo->new;
@@ -28,12 +23,13 @@ if( $api->status eq 'fail' ){
 my $mylistgroup = shift @{$api->mylistgroup};
 $mylistgroup->name($mylistgroup->name. " modified");
 say "-- registering:";
-say dump_as_yaml($mylistgroup);
+say Data::Dumper::Dumper($mylistgroup);
 
 my $updated = $nnv->update_mylistgroup($mylistgroup);
 
 say "-- registered:";
-say dump_as_yaml($updated);
+say Data::Dumper::Dumper($updated);
+
 
 1;
 __END__
